@@ -72,6 +72,14 @@ class ColorfulParser:
     def _get_ansi_decorator(cls, mode):
         return "\033[%sm" % mode
 
+    @classmethod
+    def foreground_color_exists(cls, color):
+        return hasattr(cls._forecolors, color)
+
+    @classmethod
+    def background_color_exists(cls, color):
+        return hasattr(cls._backcolors, color)
+
     @classmethod
     def _translate_to_ansi_decorator(cls, modetype, name):
         if hasattr(modetype, name):
